sequencetools.iterate_sequence_pairwise_strict
==============================================

.. autofunction:: abjad.tools.sequencetools.iterate_sequence_pairwise_strict.iterate_sequence_pairwise_strict
